@@ -1,15 +1,15 @@
-<?php 
+<?php
 /**
  * HP-UX System Class
  *
  * PHP version 5
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI HPUX OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.HPUX.inc.php 287 2009-06-26 12:11:59Z bigmichi1 $
+ * @version   SVN: $Id: class.HPUX.inc.php 596 2012-07-05 19:37:48Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -17,7 +17,7 @@
  * get all the required information from HP-UX system
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI HPUX OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
@@ -41,7 +41,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * IP of the Virtual Host Name
      *
@@ -50,16 +50,16 @@ class HPUX extends OS
     private function _ip()
     {
         if (PSI_USE_VHOST === true) {
-            $this->sys->setIp(gethostbyname($this->_hostname()));
+            $this->sys->setIp(gethostbyname($this->sys->getHostname()));
         } else {
             if (!($result = getenv('SERVER_ADDR'))) {
-                $this->sys->setIp(gethostbyname($this->_hostname()));
+                $this->sys->setIp(gethostbyname($this->sys->getHostname()));
             } else {
                 $this->sys->setIp($result);
             }
         }
     }
-    
+
     /**
      * HP-UX Version
      *
@@ -71,7 +71,7 @@ class HPUX extends OS
             $this->sys->setKernel($ret);
         }
     }
-    
+
     /**
      * UpTime
      * time the system is running
@@ -89,7 +89,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * Number of Users
      *
@@ -102,7 +102,7 @@ class HPUX extends OS
             $this->sys->setUsers($who[1]);
         }
     }
-    
+
     /**
      * Processor Load
      * optionally create a loadbar
@@ -117,7 +117,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * CPU information
      * All of the tags here are highly architecture dependant
@@ -163,7 +163,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * PCI devices
      *
@@ -190,7 +190,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * IDE devices
      *
@@ -214,7 +214,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * SCSI devices
      *
@@ -240,7 +240,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * USB devices
      *
@@ -269,7 +269,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * Network devices
      * includes also rx/tx bytes
@@ -294,7 +294,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * Physical memory information and Swap Space information
      *
@@ -332,7 +332,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * filesystem information
      *
@@ -364,7 +364,7 @@ class HPUX extends OS
             }
         }
     }
-    
+
     /**
      * Distribution
      *
@@ -373,9 +373,9 @@ class HPUX extends OS
     private function _distro()
     {
         $this->sys->setDistribution('HP-UX');
+        $this->sys->setDistributionIcon('HPUX.png');
     }
 
-    
     /**
      * get the information
      *
@@ -383,11 +383,11 @@ class HPUX extends OS
      *
      * @return Void
      */
-    function build()
+    public function build()
     {
         $this->_distro();
-        $this->_ip();
         $this->_hostname();
+        $this->_ip();
         $this->_kernel();
         $this->_uptime();
         $this->_users();
@@ -402,4 +402,3 @@ class HPUX extends OS
         $this->_filesystems();
     }
 }
-?>
