@@ -1,15 +1,15 @@
-<?php 
+<?php
 /**
  * OpenBSD System Class
  *
  * PHP version 5
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI OpenBSD OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.OpenBSD.inc.php 287 2009-06-26 12:11:59Z bigmichi1 $
+ * @version   SVN: $Id: class.OpenBSD.inc.php 621 2012-07-29 18:49:04Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -17,7 +17,7 @@
  * get all the required information from OpenBSD systems
  *
  * @category  PHP
- * @package   PSI_OS
+ * @package   PSI OpenBSD OS class
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
@@ -39,7 +39,7 @@ class OpenBSD extends BSDCommon
         $this->setPCIRegExp1("/(.*) at pci[0-9] .* \"(.*)\"/");
         $this->setPCIRegExp2("/\"(.*)\" (.*).* at [.0-9]+ irq/");
     }
-    
+
     /**
      * UpTime
      * time the system is running
@@ -51,7 +51,7 @@ class OpenBSD extends BSDCommon
         $a = $this->grabkey('kern.boottime');
         $this->sys->setUptime(time() - $a);
     }
-    
+
     /**
      * get network information
      *
@@ -78,7 +78,6 @@ class OpenBSD extends BSDCommon
         }
     }
 
-    
     /**
      * IDE information
      *
@@ -100,7 +99,7 @@ class OpenBSD extends BSDCommon
             }
         }
     }
-    
+
     /**
      * get CPU information
      *
@@ -111,9 +110,14 @@ class OpenBSD extends BSDCommon
         $dev = new CpuDevice();
         $dev->setModel($this->grabkey('hw.model'));
         $dev->setCpuSpeed($this->grabkey('hw.cpuspeed'));
-        $this->sys->setCpus($dev);
+        $ncpu = $this->grabkey('hw.ncpu');
+        if ( is_null($ncpu) || (trim($ncpu) == "") || (!($ncpu >= 1)) )
+            $ncpu = 1;
+        for ($ncpu ; $ncpu > 0 ; $ncpu--) {
+            $this->sys->setCpus($dev);
+        }
     }
-    
+
     /**
      * get icon name
      *
@@ -123,7 +127,35 @@ class OpenBSD extends BSDCommon
     {
         $this->sys->setDistributionIcon('OpenBSD.png');
     }
-    
+
+    /**
+     * Processes
+     *
+     * @return void
+     */
+    protected function _processes()
+    {
+        if (CommonFunctions::executeProgram('ps', 'aux', $bufr, PSI_DEBUG)) {
+            $lines = preg_split("/\n/", $bufr, -1, PREG_SPLIT_NO_EMPTY);
+            $processes['*'] = 0;
+            foreach ($lines as $line) {
+                if (preg_match("/^\S+\s+\d+\s+\S+\s+\S+\s+\d+\s+\d+\s+\S+\s+(\w)/", $line, $ar_buf)) {
+                    $processes['*']++;
+                    $state = $ar_buf[1];
+                    if ($state == 'I') $state = 'S'; //linux format
+                    if (isset($processes[$state])) {
+                        $processes[$state]++;
+                    } else {
+                        $processes[$state] = 1;
+                    }
+                }
+            }
+            if ($processes['*'] > 0) {
+                $this->sys->setProcesses($processes);
+            }
+        }
+    }
+
     /**
      * get the information
      *
@@ -131,12 +163,12 @@ class OpenBSD extends BSDCommon
      *
      * @return Void
      */
-    function build()
+    public function build()
     {
-        parent::buil();
+        parent::build();
         $this->_distroicon();
         $this->_network();
         $this->_uptime();
+        $this->_processes();
     }
 }
-?>
