@@ -1,4 +1,4 @@
-<?php 
+<?php
 /**
  * XML Generator class
  *
@@ -9,7 +9,7 @@
  * @author    Michael Cramer <BigMichi1@users.sourceforge.net>
  * @copyright 2009 phpSysInfo
  * @license   http://opensource.org/licenses/gpl-2.0.php GNU General Public License
- * @version   SVN: $Id: class.WebpageXML.inc.php 315 2009-09-02 15:48:31Z bigmichi1 $
+ * @version   SVN: $Id: class.WebpageXML.inc.php 661 2012-08-27 11:26:39Z namiltd $
  * @link      http://phpsysinfo.sourceforge.net
  */
  /**
@@ -31,28 +31,28 @@ class WebpageXML extends Output implements PSI_Interface_Output
      * @var XML
      */
     private $_xml;
-    
+
     /**
      * only plugin xml
      *
      * @var boolean
      */
     private $_pluginRequest = false;
-    
+
     /**
      * complete xml
      *
      * @var boolean
      */
     private $_completeXML = false;
-    
+
     /**
      * name of the plugin
      *
      * @var string
      */
     private $_pluginName = null;
-    
+
     /**
      * generate the output
      *
@@ -62,28 +62,35 @@ class WebpageXML extends Output implements PSI_Interface_Output
     {
         if (!$this->_pluginRequest) {
             // Figure out which OS we are running on, and detect support
-            if (!file_exists(APP_ROOT.'/includes/os/class.'.PHP_OS.'.inc.php')) {
-                $this->error->addError("file_exists(class.".PHP_OS.".php.inc)", PHP_OS." is not currently supported");
+            if (!file_exists(APP_ROOT.'/includes/os/class.'.PSI_OS.'.inc.php')) {
+                $this->error->addError("file_exists(class.".PSI_OS.".inc.php)", PSI_OS." is not currently supported");
             }
-            
-            // check if there is a valid sensor configuration in config.php
-            $found = false;
-            if (PSI_SENSOR_PROGRAM !== false) {
-                if (!file_exists(APP_ROOT.'/includes/mb/class.'.PSI_SENSOR_PROGRAM.'.inc.php')) {
-                    $found = false;
-                    $this->error->addError("file_exists(class.".htmlspecialchars(PSI_SENSOR_PROGRAM).".inc.php)", "specified sensor program is not supported");
+
+            // check if there is a valid sensor configuration in phpsysinfo.ini
+            $foundsp = array();
+            if ( defined('PSI_SENSOR_PROGRAM') && is_string(PSI_SENSOR_PROGRAM) ) {
+                if (preg_match(ARRAY_EXP, PSI_SENSOR_PROGRAM)) {
+                    $sensorprograms = eval(strtolower(PSI_SENSOR_PROGRAM));
                 } else {
-                    $found = true;
+                    $sensorprograms = array(strtolower(PSI_SENSOR_PROGRAM));
+                }
+                foreach ($sensorprograms as $sensorprogram) {
+                    if (!file_exists(APP_ROOT.'/includes/mb/class.'.$sensorprogram.'.inc.php')) {
+                        $this->error->addError("file_exists(class.".htmlspecialchars($sensorprogram).".inc.php)", "specified sensor program is not supported");
+                    } else {
+                        $foundsp[] = $sensorprogram;
+                    }
                 }
             }
+
             /**
-             * motherboard information available or not
+             * motherboard information
              *
-             * @var boolean
+             * @var serialized array
              */
-            define('PSI_MBINFO', $found);
-            
-            // check if there is a valid hddtemp configuration in config.php
+            define('PSI_MBINFO', serialize($foundsp));
+
+            // check if there is a valid hddtemp configuration in phpsysinfo.ini
             $found = false;
             if (PSI_HDD_TEMP !== false) {
                 $found = true;
@@ -94,30 +101,36 @@ class WebpageXML extends Output implements PSI_Interface_Output
              * @var boolean
              */
             define('PSI_HDDTEMP', $found);
-            
-            // check if there is a valid ups configuration in config.php
-            $found = false;
-            if (PSI_UPS_PROGRAM !== false) {
-                if (!file_exists(APP_ROOT.'/includes/ups/class.'.PSI_UPS_PROGRAM.'.inc.php')) {
-                    $found = false;
-                    $this->error->addError("file_exists(class.".htmlspecialchars(PSI_UPS_PROGRAM).".inc.php)", "specified UPS program is not supported");
+
+            // check if there is a valid ups configuration in phpsysinfo.ini
+            $foundup = array();
+            if ( defined('PSI_UPS_PROGRAM') && is_string(PSI_UPS_PROGRAM) ) {
+                if (preg_match(ARRAY_EXP, PSI_UPS_PROGRAM)) {
+                    $upsprograms = eval(strtolower(PSI_UPS_PROGRAM));
                 } else {
-                    $found = true;
+                    $upsprograms = array(strtolower(PSI_UPS_PROGRAM));
+                }
+                foreach ($upsprograms as $upsprogram) {
+                    if (!file_exists(APP_ROOT.'/includes/ups/class.'.$upsprogram.'.inc.php')) {
+                        $this->error->addError("file_exists(class.".htmlspecialchars($upsprogram).".inc.php)", "specified UPS program is not supported");
+                    } else {
+                        $foundup[] = $upsprogram;
+                    }
                 }
             }
             /**
-             * ups information available or not
+             * ups information
              *
-             * @var boolean
+             * @var serialized array
              */
-            define('PSI_UPSINFO', $found);
-            
+            define('PSI_UPSINFO', serialize($foundup));
+
             // if there are errors stop executing the script until they are fixed
             if ($this->error->errorsExist()) {
                 $this->error->errorsAsXML();
             }
         }
-        
+
         // Create the XML
         if ($this->_pluginRequest) {
             $this->_xml = new XML(false, $this->_pluginName);
@@ -125,7 +138,7 @@ class WebpageXML extends Output implements PSI_Interface_Output
             $this->_xml = new XML($this->_completeXML);
         }
     }
-    
+
     /**
      * render the output
      *
@@ -137,9 +150,8 @@ class WebpageXML extends Output implements PSI_Interface_Output
         header("Content-Type: text/xml\n\n");
         $xml = $this->_xml->getXml();
         echo $xml->asXML();
-        die();
     }
-    
+
     /**
      * get XML as pure string
      *
@@ -148,9 +160,10 @@ class WebpageXML extends Output implements PSI_Interface_Output
     public function getXMLString()
     {
         $xml = $this->_xml->getXml();
+
         return $xml->asXML();
     }
-    
+
     /**
      * set parameters for the XML generation process
      *
@@ -166,7 +179,7 @@ class WebpageXML extends Output implements PSI_Interface_Output
             $this->_completeXML = true;
         }
         if ($plugin) {
-            if (in_array($plugin, CommonFunctions::getPlugins())) {
+            if (in_array(strtolower($plugin), CommonFunctions::getPlugins())) {
                 $this->_pluginName = $plugin;
                 $this->_pluginRequest = true;
             }
@@ -174,4 +187,3 @@ class WebpageXML extends Output implements PSI_Interface_Output
         $this->_prepare();
     }
 }
-?>
